from distutils.core import setup

setup (
                name = 'nester-edvan',
                version = '1.0.0',
                py_modules = ['nester-edvan'],
                author = 'edvan.suporte',
                author_email = 'edvan.suporte@gmail.com',
                url = 'http://www.headfirstlabs.com',
                description = 'A simple printer of nested lists',
            )
